@@ -150,7 +150,6 @@
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
-#define HAVE_GETPAGESIZE 1
 /* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
@@ -195,6 +194,7 @@
 #define HAVE_PTHREAD_ATTR_GETSTACKSIZE 1
 #define HAVE_PTHREAD_ATTR_SETSCOPE 1
 #define HAVE_PTHREAD_ATTR_SETSTACKSIZE 1
+#define HAVE_PTHREAD_GETATTR_NP 1
 /* #undef HAVE_PTHREAD_CONDATTR_CREATE */
 #define HAVE_PTHREAD_GETAFFINITY_NP 1
 #define HAVE_PTHREAD_KEY_DELETE 1
@@ -532,16 +532,16 @@
 
 #define MYSQL_VERSION_MAJOR 11
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 3
+#define MYSQL_VERSION_PATCH 4
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 11.4.3"
+#define PACKAGE_STRING "MySQL Server 11.4.4"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "11.4.3"
-#define VERSION "11.4.3"
+#define PACKAGE_VERSION "11.4.4"
+#define VERSION "11.4.4"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
